@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -293,7 +293,7 @@ def gridplot(
             else:
                 raise ValueError("Only UIElement and LayoutDOM items can be inserted into a grid")
 
-    def merge(cls: Type[Tool], group: list[Tool]):
+    def merge(cls: type[Tool], group: list[Tool]):
         if issubclass(cls, (SaveTool, CopyTool, ExamineTool, FullscreenTool)):
             return cls()
         else:
@@ -504,28 +504,33 @@ def grid(children: Any = [], sizing_mode: SizingModeType | None = None, nrows: i
 T = TypeVar("T", bound=Tool)
 MergeFn: TypeAlias = Callable[[Type[T], List[T]], Union[Tool, ToolProxy, None]]
 
-def group_tools(tools: list[Tool | ToolProxy], *, merge: MergeFn[Tool] | None = None) -> list[Tool | ToolProxy]:
+def group_tools(tools: list[Tool | ToolProxy], *, merge: MergeFn[Tool] | None = None,
+        ignore: set[str] | None = None) -> list[Tool | ToolProxy]:
     """ Group common tools into tool proxies. """
     @dataclass
     class ToolEntry:
         tool: Tool
         props: Any
 
-    by_type: defaultdict[Type[Tool], list[ToolEntry]] = defaultdict(list)
+    by_type: defaultdict[type[Tool], list[ToolEntry]] = defaultdict(list)
     computed: list[Tool | ToolProxy] = []
 
+    if ignore is None:
+        ignore = {"overlay", "renderers"}
+
     for tool in tools:
         if isinstance(tool, ToolProxy):
             computed.append(tool)
         else:
             props = tool.properties_with_values()
-            if "overlay" in props:
-                del props["overlay"]
+            for attr in ignore:
+                if attr in props:
+                    del props[attr]
             by_type[tool.__class__].append(ToolEntry(tool, props))
 
     for cls, entries in by_type.items():
         if merge is not None:
-            merged = merge(cls, [entry.tool for entry in entries ])
+            merged = merge(cls, [entry.tool for entry in entries])
             if merged is not None:
                 computed.append(merged)
                 continue
@@ -594,8 +599,8 @@ def _create_grid(iterable: Iterable[UIElement | list[UIElement]], sizing_mode: S
             return_list.append(item)
         else:
             raise ValueError(
-                """Only LayoutDOM items can be inserted into a layout.
-                Tried to insert: %s of type %s""" % (item, type(item))
+                f"""Only LayoutDOM items can be inserted into a layout.
+                Tried to insert: {item} of type {type(item)}"""
             )
     if layer % 2 == 0:
         return column(children=return_list, sizing_mode=sizing_mode, **kwargs)
